@@ -97,7 +97,7 @@ class ChangeLog(object):
                                stdin=subprocess.PIPE,
                                stdout=subprocess.PIPE,
                                stderr=subprocess.PIPE)
-        (stdout, stderr) = cmd.communicate(self._contents.encode())
+        (stdout, stderr) = cmd.communicate(self._contents.encode('utf-8'))
         if cmd.returncode:
             raise ParseChangeLogError("Failed to parse changelog. "
                                       "dpkg-parsechangelog said:\n%s" % stderr.decode().strip())
@@ -118,13 +118,19 @@ class ChangeLog(object):
                 cp['Upstream-Version'], cp['Debian-Version'] = cp['NoEpoch-Version'].rsplit('-', 1)
             else:
                 cp['Debian-Version'] = cp['NoEpoch-Version']
+
+            # py3's email.message_from_string() saves dpkg-parsechangelog's
+            # first newline from the "Changes" field.
+            changes = cp['Changes'].lstrip("\n")
+            del cp['Changes']
+            cp['Changes'] = changes
         except TypeError:
             raise ParseChangeLogError(output.split('\n')[0])
 
         self._cp = cp
 
     def _read(self):
-        with open(self.filename) as f:
+        with open(self.filename, encoding='utf-8') as f:
             self._contents = f.read()
 
     def __getitem__(self, item):
@@ -259,9 +265,9 @@ class ChangeLog(object):
             msg = None
 
         if author:
-            env['DEBFULLNAME'] = author
+            env['DEBFULLNAME'] = author.encode('utf-8')
         if email:
-            env['DEBEMAIL'] = email
+            env['DEBEMAIL'] = email.encode('utf-8')
 
         if distribution:
             args.append("--distribution=%s" % distribution)
@@ -275,8 +281,8 @@ class ChangeLog(object):
         dch = Command('debchange', args, extra_env=env)
         dch([], quiet=True)
         if msg:
-            old_cl = open("debian/changelog", "r")
-            new_cl = open("debian/changelog.bak", "w")
+            old_cl = open("debian/changelog", "r", encoding='utf-8')
+            new_cl = open("debian/changelog.bak", "w", encoding='utf-8')
             for line in old_cl:
                 if line == "  * [[[insert-git-dch-commit-message-here]]]\n":
                     print("  * " + msg[0], file=new_cl)
