@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2012 Guido Günther <agx@sigxcpu.org>
+# (C) 2012,2017 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -57,7 +57,7 @@ class Uscan(object):
         >>> u._parse('')
         Traceback (most recent call last):
         ...
-        UscanError: Couldn't find 'upstream-url' in uscan output
+        gbp.deb.uscan.UscanError: Couldn't find 'upstream-url' in uscan output
         """
         source = None
         self._uptodate = False
@@ -146,17 +146,17 @@ class Uscan(object):
         ... "to example.com:80 (Bad hostname)</warnings>")
         Traceback (most recent call last):
         ...
-        UscanError: Uscan failed: uscan warning: In watchfile debian/watch, reading webpage
+        gbp.deb.uscan.UscanError: Uscan failed: uscan warning: In watchfile debian/watch, reading webpage
         http://a.b/ failed: 500 Cant connect to example.com:80 (Bad hostname)
         >>> u._raise_error("<errors>uscan: Can't use --verbose if "
         ... "you're using --dehs!</errors>")
         Traceback (most recent call last):
         ...
-        UscanError: Uscan failed: uscan: Can't use --verbose if you're using --dehs!
+        gbp.deb.uscan.UscanError: Uscan failed: uscan: Can't use --verbose if you're using --dehs!
         >>> u = u._raise_error('')
         Traceback (most recent call last):
         ...
-        UscanError: Uscan failed - debug by running 'uscan --verbose'
+        gbp.deb.uscan.UscanError: Uscan failed - debug by running 'uscan --verbose'
         """
         msg = None
 
@@ -176,7 +176,7 @@ class Uscan(object):
                               '--dehs'],
                              cwd=self._dir,
                              stdout=subprocess.PIPE)
-        out = p.communicate()[0]
+        out = p.communicate()[0].decode()
         # uscan exits with 1 in case of uptodate and when an error occurred.
         # Don't fail in the uptodate case:
         self._parse_uptodate(out)
