@@ -19,6 +19,7 @@ import warnings
 
 notify_module = None
 
+
 def enable_notifications():
     global notify_module
 
@@ -26,18 +27,21 @@ def enable_notifications():
         # Avoid GTK+ cannot open display warning:
         warnings.simplefilter("ignore")
         try:
-            import pynotify
-            notify_module = pynotify
+            import notify2
+            notify_module = notify2
         except (ImportError, RuntimeError):
             return False
 
-    return notify_module.init("git-buildpackage")
+    try:
+        return notify_module.init("git-buildpackage")
+    except Exception:
+        return False
 
 
 def build_msg(cp, success):
     summary = "Gbp %s" % ["failed", "successful"][success]
     msg = ("Build of %s %s %s" %
-            (cp['Source'], cp['Version'], ["failed", "succeeded"][success]))
+           (cp['Source'], cp['Version'], ["failed", "succeeded"][success]))
 
     return summary, msg
 
@@ -67,4 +71,3 @@ def notify(summary, message, notify_opt):
         return [True, False][notify_opt.is_on()]
 
     return notify_opt.do(send_notification, summary, message)
-
