@@ -22,12 +22,12 @@ from __future__ import print_function
 
 import sys
 import os
-from six.moves import urllib
+import urllib
 import subprocess
 import tty
 import termios
 import re
-from six.moves import configparser
+import configparser
 
 from gbp.deb.changelog import ChangeLog, NoChangeLogError
 from gbp.command_wrappers import (CommandExecFailed, GitCommand)
@@ -334,7 +334,7 @@ def do_create(options):
             print(cmd)
 
         proc = subprocess.Popen(cmd, stdin=subprocess.PIPE)
-        proc.communicate(remote_script)
+        proc.communicate(remote_script.encode())
         if proc.returncode:
             raise GbpError("Error creating remote repository")
 
