@@ -192,7 +192,7 @@ def prepare_pristine_tar(archive, pkg, version):
     """
     linked = False
     if os.path.isdir(archive):
-        return None
+        return None, None
 
     ext = os.path.splitext(archive)[1]
     if ext in ['.tgz', '.tbz2', '.tlz', '.txz']:
@@ -424,6 +424,19 @@ def set_bare_repo_options(options):
         options.merge = False
 
 
+def rollback(repo, options):
+    if repo and repo.has_rollbacks() and options.rollback:
+        gbp.log.err("Error detected, Will roll back changes.")
+        try:
+            repo.rollback()
+            # Make sure the very last line as an error message
+            gbp.log.err("Rolled back changes after import error.")
+        except Exception as e:
+            gbp.log.err("%s" % e)
+            gbp.log.err("Clean up manually and please report a bug: %s" %
+                        repo.rollback_errors)
+
+
 def build_parser(name):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name), prefix='',
@@ -611,10 +624,16 @@ def main(argv):
             if is_empty:
                 repo.create_branch(branch=options.debian_branch, rev=commit)
                 repo.force_head(options.debian_branch, hard=True)
+                # In an empty repo avoid master branch defaulted to by
+                # git and check out debian branch instead.
+                if not repo.bare:
+                    cur = repo.branch
+                    if cur != options.debian_branch:
+                        repo.set_branch(options.debian_branch)
+                        repo.delete_branch(cur)
             elif options.merge:
                 repo.rrr_branch(options.debian_branch)
                 debian_branch_merge(repo, tag, version, options)
-                postimport_hook(repo, tag, version, options)
 
             # Update working copy and index if we've possibly updated the
             # checked out branch
@@ -622,6 +641,8 @@ def main(argv):
             if current_branch in [options.upstream_branch,
                                   repo.pristine_tar_branch]:
                 repo.force_head(current_branch, hard=True)
+
+            postimport_hook(repo, tag, version, options)
         except (gbpc.CommandExecFailed, GitRepositoryError) as err:
             msg = str(err) or 'Unknown error, please report a bug'
             raise GbpError("Import of %s failed: %s" % (upstream.path, msg))
@@ -631,16 +652,7 @@ def main(argv):
         if str(err):
             gbp.log.err(err)
         ret = 1
-        if repo and repo.has_rollbacks() and options.rollback:
-            gbp.log.err("Error detected, Will roll back changes.")
-            try:
-                repo.rollback()
-                # Make sure the very last line as an error message
-                gbp.log.err("Rolled back changes after import error.")
-            except Exception as e:
-                gbp.log.err("%s" % e)
-                gbp.log.err("Clean up manually and please report a bug: %s" %
-                            repo.rollback_errors)
+        rollback(repo, options)
 
     if pristine_orig and linked and not options.symlink_orig:
         os.unlink(pristine_orig)
