@@ -33,7 +33,7 @@ from gbp.git.modifier import GitModifier
 from gbp.command_wrappers import GitCommand, CommandExecFailed
 from gbp.errors import GbpError
 from gbp.patch_series import PatchSeries, Patch
-from gbp.pkg import parse_archive_filename
+from gbp.pkg import Archive
 from gbp.rpm import (SpecFile, NoSpecError, guess_spec, guess_spec_repo,
                      spec_from_repo)
 from gbp.scripts.common import ExitCodes
@@ -41,7 +41,7 @@ from gbp.scripts.common.pq import (is_pq_branch, pq_branch_name, pq_branch_base,
                                    parse_gbp_commands, format_patch, format_diff,
                                    switch_to_pq_branch, apply_single_patch,
                                    apply_and_commit_patch,
-                                   drop_pq, switch_pq)
+                                   drop_pq)
 
 from gbp.scripts.common.buildpackage import dump_tree
 
@@ -86,9 +86,10 @@ def generate_patches(repo, start, end, outdir, options):
     merges = repo.get_commits(start, end_commit, options=['--merges'])
     if merges:
         # Shorten SHA1s
-        start_sha1 = repo.rev_parse(start, short=7)
-        merge_sha1 = repo.rev_parse(merges[0], short=7)
-        patch_fn = format_diff(outdir, None, repo, start_sha1, merge_sha1)
+        start_sha1 = repo.rev_parse(start, short=options.abbrev)
+        merge_sha1 = repo.rev_parse(merges[0], short=options.abbrev)
+        patch_fn = format_diff(outdir, None, repo, start_sha1, merge_sha1,
+                               abbrev=options.abbrev)
         if patch_fn:
             gbp.log.info("Merge commits found! Diff between %s..%s written "
                          "into one monolithic diff" % (start_sha1, merge_sha1))
@@ -104,7 +105,8 @@ def generate_patches(repo, start, end, outdir, options):
                                                   ('if', 'ifarch'))
         if 'ignore' not in cmds:
             patch_fn = format_patch(outdir, repo, info, patches,
-                                    options.patch_numbers)
+                                    numbered=options.patch_numbers,
+                                    abbrev=options.abbrev)
             if patch_fn:
                 commands[os.path.basename(patch_fn)] = cmds
         else:
@@ -114,7 +116,8 @@ def generate_patches(repo, start, end, outdir, options):
     if end_commit != end:
         gbp.log.info("Generating diff file %s..%s" % (end_commit, end))
         patch_fn = format_diff(outdir, None, repo, end_commit, end,
-                               options.patch_export_ignore_path)
+                               options.patch_export_ignore_path,
+                               abbrev=options.abbrev)
         if patch_fn:
             patches.append(patch_fn)
 
@@ -224,10 +227,10 @@ def safe_patches(queue):
     safequeue = PatchSeries()
 
     if len(queue) > 0:
-        gbp.log.debug("Safeing patches '%s' in '%s'" %
+        gbp.log.debug("Saving patches '%s' in '%s'" %
                       (os.path.dirname(queue[0].path), tmpdir))
     for patch in queue:
-        base, _archive_fmt, comp = parse_archive_filename(patch.path)
+        base, _archive_fmt, comp = Archive.parse_filename(patch.path)
         uncompressors = {'gzip': gzip.open, 'bzip2': bz2.BZ2File}
         if comp in uncompressors:
             gbp.log.debug("Uncompressing '%s'" % os.path.basename(patch.path))
@@ -237,11 +240,11 @@ def safe_patches(queue):
             raise GbpError("Unsupported patch compression '%s', giving up"
                            % comp)
         else:
-            src = open(patch.path, 'r')
+            src = open(patch.path, 'rb')
             dst_name = os.path.join(tmpdir, os.path.basename(patch.path))
 
-        dst = open(dst_name, 'w')
-        dst.writelines(src)
+        dst = open(dst_name, 'wb')
+        dst.write(src.read())
         src.close()
         dst.close()
 
@@ -345,6 +348,16 @@ def rebase_pq(repo, options):
     GitCommand("rebase")([upstream_commit])
 
 
+def switch_pq(repo, current):
+    """Switch to patch-queue branch if on base branch and vice versa"""
+    if is_pq_branch(current):
+        base = pq_branch_base(current)
+        gbp.log.info("Switching to %s" % base)
+        repo.checkout(base)
+    else:
+        switch_to_pq_branch(repo, current)
+
+
 def usage_msg():
     return """%prog [options] action - maintain patches on a patch queue branch
 Ations:
@@ -382,6 +395,7 @@ def build_parser(name):
     parser.add_config_file_option(option_name="color-scheme",
                                   dest="color_scheme")
     parser.add_config_file_option(option_name="tmp-dir", dest="tmp_dir")
+    parser.add_config_file_option(option_name="abbrev", dest="abbrev", type="int")
     parser.add_config_file_option(option_name="upstream-tag",
                                   dest="upstream_tag")
     parser.add_config_file_option(option_name="spec-file", dest="spec_file")
