@@ -22,8 +22,6 @@ import shutil
 import tempfile
 from nose.tools import assert_raises, eq_, ok_  # pylint: disable=E0611
 
-import six
-
 from gbp.errors import GbpError
 from gbp.rpm import (SpecFile, SrcRpmFile, NoSpecError, guess_spec,
                      guess_spec_repo, spec_from_repo)
@@ -299,7 +297,7 @@ class TestSpecFile(RpmTestBase):
         spec = SpecFileTester(spec_filepath)
 
         # Check all the tags
-        for name, val in six.iteritems(spec.protected('_tags')):
+        for name, val in spec.protected('_tags').items():
             rval = None
             if name in ('version', 'release', 'epoch'):
                 rval = '0'
