@@ -16,6 +16,7 @@
 #    along with this program; if not, please see
 #    <http://www.gnu.org/licenses/>
 
+import glob
 import hashlib
 import os
 import subprocess
@@ -142,6 +143,18 @@ class TestBuildpackage(ComponentTestBase):
         for t in tarballs:
             self.assertTrue(os.path.exists(t), "Tarball %s not found" % t)
 
+    @RepoFixtures.quilt30()
+    def test_pristine_tar_commit(self, repo):
+        """Test that committing to pristine-tar branch after building tarballs works"""
+        assert_false(repo.has_branch('pristine-tar'), "Pristine-tar branch must not exist")
+        ret = buildpackage(['arg0',
+                            '--git-builder=/bin/true',
+                            '--git-pristine-tar-commit'])
+        ok_(ret == 0, "Building the package failed")
+        assert_true(repo.has_branch('pristine-tar'), "Pristine-tar branch must exist")
+        eq_(repo.ls_tree('pristine-tar'), {b'hello-debhelper_2.8.orig.tar.gz.id',
+                                           b'hello-debhelper_2.8.orig.tar.gz.delta'})
+
     @RepoFixtures.quilt30()
     def test_sloppy_tarball_generation(self, repo):
         """Test that generating tarball from Debian branch works"""
@@ -163,17 +176,39 @@ class TestBuildpackage(ComponentTestBase):
         self._test_buildpackage(repo, ['--git-export-dir=../foo/bar'])
         ok_(os.path.exists('../foo/bar'))
 
+    @RepoFixtures.quilt30_additional_tarball()
+    def test_export_dir_additional_tar(self, repo):
+        """Test that building with a export dir and additional tarball works"""
+        self._test_buildpackage(repo, ['--git-export-dir=../foo/bar',
+                                       '--git-no-purge',
+                                       '--git-component=foo'])
+        # Check that all needed tarballs end up in the build-area
+        eq_(sorted(glob.glob('../foo/bar/*')), ['../foo/bar/hello-debhelper-2.8',
+                                                '../foo/bar/hello-debhelper_2.8.orig-foo.tar.gz',
+                                                '../foo/bar/hello-debhelper_2.8.orig.tar.gz'])
+        # Check that directories from additional tarballs get exported too
+        ok_(os.path.exists('../foo/bar/hello-debhelper-2.8/foo'))
+
     @RepoFixtures.overlay()
     def test_export_dir_overlay(self, repo):
         """Test that building in overlay mode with export dir works"""
         tarball_dir = os.path.dirname(DEFAULT_OVERLAY)
         self._test_buildpackage(repo, ['--git-overlay',
-                                       '--git-compression=gzip',
+                                       '--git-compression=auto',
                                        '--git-tarball-dir=%s' % tarball_dir,
                                        '--git-no-purge',
-                                       '--git-export-dir=../foo'])
-        ok_(os.path.exists('../foo/hello-debhelper-2.8/configure'))
-        ok_(os.path.exists('../foo/hello-debhelper-2.8/debian/changelog'))
+                                       '--git-component=foo',
+                                       '--git-export-dir=../overlay'])
+        # Check if main tarball got unpacked
+        ok_(os.path.exists('../overlay/hello-debhelper-2.8/configure'))
+        # Check if debian dir is there
+        ok_(os.path.exists('../overlay/hello-debhelper-2.8/debian/changelog'))
+        # Check if additional tarball got unpacked
+        ok_(os.path.exists('../overlay/hello-debhelper-2.8/foo/test1'))
+        # Check if upstream tarballs is in export_dir
+        eq_(sorted(glob.glob('../overlay/*')), ['../overlay/hello-debhelper-2.8',
+                                                '../overlay/hello-debhelper_2.8.orig-foo.tar.gz',
+                                                '../overlay/hello-debhelper_2.8.orig.tar.gz'])
 
     @RepoFixtures.quilt30()
     def test_export_wc_buildpackage(self, repo):
